@@ -126,6 +126,25 @@ class CustomEmailField(EmailField, BaseCustomField):
     field_type = _("E-mail")
 
 
+class CustomIPField(GenericIPAddressField, BaseCustomField):
+    """
+    GenericIPAddressField
+    """
+    field_type = _("Indirizzo IP")
+
+class CustomMACField(CustomCharField, BaseCustomField):
+    """
+    GenericIPAddressField
+    """
+    field_type = _("MAC Address")
+
+    def raise_error(self, name, cleaned_data, **kwargs):
+        if not cleaned_data: return []
+
+        # Only valid sequences
+        if not re.match('([0-9a-fA-F]:?){12}', str(cleaned_data)):
+            return [_("Formato non valido"),]
+
 class CustomChoiceField(ChoiceField, BaseCustomField):
     """
     ChoiceField
@@ -200,9 +219,11 @@ class CustomFileField(FileField, BaseCustomField):
                 msg_tmpl = WRONG_SIZE
                 msg = msg_tmpl.format(filesizeformat(max_upload_size),
                                       filesizeformat(data.size))
-            elif len(data._name) > attach_max_len:
+            # elif len(data._name) > attach_max_len:
+            elif len(data.name) > attach_max_len:
                 msg_tmpl = WRONG_LENGTH
-                msg = msg_tmpl.format(attach_max_len, len(data._name))
+                # msg = msg_tmpl.format(attach_max_len, len(data._name))
+                msg = msg_tmpl.format(attach_max_len, len(data.name))
             if msg: errors.append(msg)
         return errors
 
